pub struct SqlTypeName(/* private fields */);Expand description
A SQL type name label.
Implementations
Sourceimpl SqlTypeName
impl SqlTypeName
Sourcepub fn new(input: impl AsRef<str>) -> Result<Self, SqlTypeError>
pub fn new(input: impl AsRef<str>) -> Result<Self, SqlTypeError>
Creates a SQL type name label.
Errors
Returns SqlTypeError when the label is empty or contains control characters.
Sourcepub fn from_scalar(scalar: SqlScalarType) -> Self
pub fn from_scalar(scalar: SqlScalarType) -> Self
Creates a canonical type name from a scalar type.